import 'package:flutter_firebase_basic_tools/logic/url_launcher.dart';
import 'package:flutter_firebase_basic_tools/widgets/background_image_with_gradient_color.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:flutter_firebase_basic_tools/logic/my_flutter_app_icons.dart'
    as custicon;

class ContactUsContainer extends StatefulWidget {
  const ContactUsContainer({
    @required this.texts,
    @required this.landingClass,
    this.iconColor,
    this.containerBackgroundColor,
    this.containerBackgroundImage,
    this.cardBackgroundColor,
    this.cardBackgroundImage,
    this.facebookUrl,
    this.youtubeUrl,
    this.instagramUrl,
    this.twitterUrl,
    @required this.email,
    @required this.feedbackMessage,
  });

  final List<String> texts;
  final landingClass;
  final Color iconColor;
  final Color containerBackgroundColor;
  final String containerBackgroundImage;
  final Color cardBackgroundColor;
  final String cardBackgroundImage;
  final String facebookUrl;
  final String youtubeUrl;
  final String instagramUrl;
  final String twitterUrl;
  final String email;
  final String feedbackMessage;

  @override
  _ContactUsContainerState createState() => _ContactUsContainerState();
}

class _ContactUsContainerState extends State<ContactUsContainer> {
  TextEditingController nameInputController = TextEditingController();
  TextEditingController emailInputController = TextEditingController();
  TextEditingController subjectInputController = TextEditingController();
  TextEditingController messageInputController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).orientation == Orientation.portrait;

    return Container(
      height: isPortrait
          ? (MediaQuery.of(context).size.height * 1.8)
          : (MediaQuery.of(context).size.height),
      width: MediaQuery.of(context).size.width,
      child: BackgroundImageWithGradientColor(
        height: isPortrait
            ? (MediaQuery.of(context).size.height * 1.8)
            : (MediaQuery.of(context).size.height),
        width: MediaQuery.of(context).size.width,
        boxFit: BoxFit.cover,
        backgroundImagePath: widget.containerBackgroundImage,
        linearGradient: LinearGradient(
          begin: FractionalOffset.centerLeft,
          end: FractionalOffset.centerRight,
          colors: [
            Colors.black.withOpacity(0.7),
            Colors.black.withOpacity(0.7),
          ],
          stops: [0.0, 1.0],
        ),
        child: Column(
          children: <Widget>[
            Spacer(flex: 1),
            Expanded(
              flex: 1,
              child: FractionallySizedBox(
                widthFactor: 0.7,
                child: Text(
                  widget.texts[0],
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    color: Colors.white,
                    fontSize: 40,
                    //fontWeight: FontWeight.bold,
                  ),
                ),
              ),
            ),
            Expanded(
              flex: isPortrait ? 2 : 1,
              child: FractionallySizedBox(
                widthFactor: 0.55,
                child: Text(
                  widget.texts[1],
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    color: Colors.white,
                    fontSize: 18,
                  ),
                ),
              ),
            ),
            Expanded(
              flex: isPortrait ? 10 : 6,
              child: FractionallySizedBox(
                widthFactor: isPortrait ? 0.8 : 0.8,
                child: Card(
                  elevation: 5,
                  semanticContainer: true,
                  child: Container(
                    decoration: BoxDecoration(
                      image: widget.cardBackgroundImage != null
                          ? DecorationImage(
                              fit: BoxFit.fitHeight,
                              image: AssetImage(
                                widget.cardBackgroundImage,
                              ),
                            )
                          : null,
                      color: widget.cardBackgroundColor,
                    ),
                    child: FractionallySizedBox(
                      widthFactor: isPortrait ? 0.8 : 1,
                      child: Flex(
                        direction: isPortrait ? Axis.vertical : Axis.horizontal,
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: <Widget>[
                          Spacer(flex: 1),
                          Expanded(
                            flex: 10,
                            child: Column(
                              children: <Widget>[
                                isPortrait ? Container() : Spacer(flex: 1),
                                Expanded(
                                  flex: 1,
                                  child: TextFormField(
                                    controller: nameInputController,
                                    decoration: InputDecoration(
                                      hintText: 'What do people call you?',
                                      labelText: widget.texts[2],
                                    ),
                                    onSaved: (String value) {},
                                    validator: (String value) {
                                      return value.contains('@')
                                          ? 'Do not use the @ char.'
                                          : null;
                                    },
                                  ),
                                ),
                                Expanded(
                                  flex: 1,
                                  child: TextFormField(
                                    controller: emailInputController,
                                    decoration: InputDecoration(
                                      labelText: widget.texts[3],
                                    ),
                                    onSaved: (String value) {},
                                    validator: (String value) {
                                      return value.contains('@')
                                          ? 'Do not use the @ char.'
                                          : null;
                                    },
                                  ),
                                ),
                                Expanded(
                                  flex: 1,
                                  child: TextFormField(
                                    controller: subjectInputController,
                                    decoration: InputDecoration(
                                      labelText: widget.texts[4],
                                    ),
                                    onSaved: (String value) {},
                                    validator: (String value) {
                                      return value.contains('@')
                                          ? 'Do not use the @ char.'
                                          : null;
                                    },
                                  ),
                                ),
                                Expanded(
                                  flex: 1,
                                  child: TextFormField(
                                    controller: messageInputController,
                                    decoration: InputDecoration(
                                      labelText: widget.texts[5],
                                    ),
                                    onSaved: (String value) {},
                                    validator: (String value) {
                                      return value.contains('@')
                                          ? 'Do not use the @ char.'
                                          : null;
                                    },
                                  ),
                                ),
                                Expanded(
                                  flex: 1,
                                  child: Row(
                                    children: <Widget>[
                                      isPortrait
                                          ? Spacer(flex: 1)
                                          : Container(),
                                      Expanded(
                                        flex: 2,
                                        child: RaisedButton(
                                          color: widget.iconColor,
                                          onPressed: () {
                                            String newMessage = nameInputController
                                                    .text +
                                                " has a message for you! \n\n Email: " +
                                                emailInputController.text +
                                                "\n\n Message: " +
                                                messageInputController.text;

                                            FirebaseFirestore.instance
                                                .collection("emails")
                                                .doc()
                                                .set({
                                                  "to": widget.email,
                                                  "message": {
                                                    "subject":
                                                        "Message from contact us section: " +
                                                            '"' +
                                                            subjectInputController
                                                                .text +
                                                            '"',
                                                    "text": newMessage,
                                                    //"html": 'This is the <code>HTML</code> section of the email body.',
                                                  }
                                                })
                                                .then((value) => {
                                                      nameInputController
                                                          .clear(),
                                                      emailInputController
                                                          .clear(),
                                                      subjectInputController
                                                          .clear(),
                                                      messageInputController
                                                          .clear(),
                                                      widget
                                                          .landingClass
                                                          .scaffoldKey
                                                          .currentState
                                                          .showSnackBar(
                                                              SnackBar(
                                                        content: Text(widget
                                                            .feedbackMessage),
                                                        duration: Duration(
                                                            seconds: 2),
                                                      )),
                                                    })
                                                .catchError(
                                                    (err) => print(err));
                                          },
                                          child: Row(
                                            children: <Widget>[
                                              Spacer(flex: 1),
                                              Expanded(
                                                flex: 5,
                                                child: Icon(
                                                  custicon.MyFlutterApp
                                                      .paper_plane_empty,
                                                  color: Colors.white,
                                                  size: 16,
                                                ),
                                              ),
                                              Spacer(flex: 1),
                                              Expanded(
                                                flex: 7,
                                                child: Text(
                                                  widget.texts[6],
                                                  textAlign: TextAlign.center,
                                                  style: TextStyle(
                                                    color: Colors.white,
                                                    fontSize: 12,
                                                    //fontWeight: FontWeight.bold,
                                                  ),
                                                ),
                                              ),
                                              Spacer(flex: 1),
                                            ],
                                          ),
                                        ),
                                      ),
                                      Spacer(flex: isPortrait ? 1 : 9),
                                    ],
                                  ),
                                ),
                                isPortrait ? Container() : Spacer(flex: 1),
                              ],
                            ),
                          ),
                          isPortrait ? Container() : Spacer(flex: 1),
                          Expanded(
                            flex: isPortrait ? 10 : 4,
                            child: Column(
                              children: <Widget>[
                                Spacer(flex: isPortrait ? 1 : 4),
                                Expanded(
                                  flex: 1,
                                  child: Icon(
                                    Icons.location_on,
                                    color: widget.iconColor,
                                  ),
                                ),
                                Spacer(flex: 1),
                                Expanded(
                                  flex: 3,
                                  child: Text(
                                    widget.texts[7],
                                    textAlign: TextAlign.center,
                                    style: TextStyle(
                                      color: Colors.black,
                                      fontSize: 18,
                                      //fontWeight: FontWeight.bold,
                                    ),
                                  ),
                                ),
                                Spacer(flex: 2),
                                Expanded(
                                  flex: 1,
                                  child: Icon(
                                    Icons.phone,
                                    color: widget.iconColor,
                                  ),
                                ),
                                Spacer(flex: 1),
                                Expanded(
                                  flex: 2,
                                  child: Text(
                                    widget.texts[8],
                                    textAlign: TextAlign.center,
                                    style: TextStyle(
                                      color: Colors.black,
                                      fontSize: 18,
                                      //fontWeight: FontWeight.bold,
                                    ),
                                  ),
                                ),
                                Spacer(flex: 2),
                                Expanded(
                                  flex: 1,
                                  child: Icon(
                                    Icons.email,
                                    color: widget.iconColor,
                                  ),
                                ),
                                Spacer(flex: 1),
                                Expanded(
                                  flex: 4,
                                  child: Text(
                                    widget.texts[9],
                                    textAlign: TextAlign.center,
                                    style: TextStyle(
                                      color: Colors.black,
                                      fontSize: 18,
                                      //fontWeight: FontWeight.bold,
                                    ),
                                  ),
                                ),
                                Spacer(flex: 1),
                                Expanded(
                                  flex: 3,
                                  child: Row(
                                    children: <Widget>[
                                      Spacer(flex: 1),
                                      widget.facebookUrl != null
                                          ? Expanded(
                                              flex: 5,
                                              child: IconButton(
                                                onPressed: () async {
                                                  launchInBrowser(
                                                      widget.facebookUrl);
                                                },
                                                icon: Icon(
                                                  custicon.MyFlutterApp
                                                      .facebook_squared,
                                                  color: widget.iconColor,
                                                ),
                                              ),
                                            )
                                          : Container(),
                                      widget.youtubeUrl != null
                                          ? Expanded(
                                              flex: 5,
                                              child: IconButton(
                                                onPressed: () async {
                                                  launchInBrowser(
                                                      widget.youtubeUrl);
                                                },
                                                icon: Icon(
                                                  custicon.MyFlutterApp
                                                      .youtube_play,
                                                  color: widget.iconColor,
                                                ),
                                              ),
                                            )
                                          : Container(),
                                      widget.instagramUrl != null
                                          ? Expanded(
                                              flex: 5,
                                              child: IconButton(
                                                onPressed: () async {
                                                  launchInBrowser(
                                                      widget.instagramUrl);
                                                },
                                                icon: Icon(
                                                  custicon
                                                      .MyFlutterApp.instagram,
                                                  color: widget.iconColor,
                                                ),
                                              ),
                                            )
                                          : Container(),
                                      widget.twitterUrl != null
                                          ? Expanded(
                                              flex: 5,
                                              child: IconButton(
                                                onPressed: () async {
                                                  launchInBrowser(
                                                      widget.twitterUrl);
                                                },
                                                icon: Icon(
                                                  custicon.MyFlutterApp.twitter,
                                                  color: widget.iconColor,
                                                ),
                                              ),
                                            )
                                          : Container(),
                                      Spacer(flex: 1),
                                    ],
                                  ),
                                ),
                                isPortrait ? Container() : Spacer(flex: 6),
                              ],
                            ),
                          ),
                          Spacer(flex: 1),
                        ],
                      ),
                    ),
                  ),
                ),
              ),
            ),
            Spacer(flex: 1),
          ],
        ),
      ),
    );
  }
}
